pub struct ClickUpMetadata {
pub statuses: Vec<ClickUpStatus>,
pub custom_fields: Vec<ClickUpCustomField>,
}Expand description
Metadata for a ClickUp list, used for dynamic schema enrichment.
In cloud mode, this is loaded from the database (project.issueTrackerMetadata). In CLI mode, this can be fetched from the ClickUp API.
Fields
statuses: Vec<ClickUpStatus>custom_fields: Vec<ClickUpCustomField>Custom fields defined for the list.