pub struct ClickUpTask {Show 18 fields
pub id: String,
pub custom_id: Option<String>,
pub name: String,
pub description: Option<String>,
pub text_content: Option<String>,
pub status: ClickUpStatus,
pub priority: Option<ClickUpPriority>,
pub tags: Vec<ClickUpTag>,
pub assignees: Vec<ClickUpUser>,
pub creator: Option<ClickUpUser>,
pub url: String,
pub date_created: Option<String>,
pub date_updated: Option<String>,
pub parent: Option<String>,
pub subtasks: Option<Vec<ClickUpTask>>,
pub dependencies: Option<Vec<Value>>,
pub linked_tasks: Option<Vec<ClickUpLinkedTask>>,
pub attachments: Vec<ClickUpAttachment>,
}Fields
id: Stringcustom_id: Option<String>name: Stringdescription: Option<String>text_content: Option<String>status: ClickUpStatuspriority: Option<ClickUpPriority>assignees: Vec<ClickUpUser>creator: Option<ClickUpUser>url: Stringdate_created: Option<String>date_updated: Option<String>parent: Option<String>subtasks: Option<Vec<ClickUpTask>>dependencies: Option<Vec<Value>>Dependencies (blocking/waiting relationships).
Uses serde_json::Value for flexible parsing of undocumented API shape.
linked_tasks: Option<Vec<ClickUpLinkedTask>>Linked tasks (non-dependency relationships).
attachments: Vec<ClickUpAttachment>Attachments uploaded to the task.
The ClickUp API returns this under attachments on the task object.
It may be absent for older tasks or tasks without uploads.